#[non_exhaustive]pub enum ThinkingLevel {
Minimal,
Low,
Medium,
High,
}Expand description
Controls the depth of extended thinking for models that support it.
Higher levels allow the model more internal reasoning steps at the cost of increased latency and token usage.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations