Module error

Module error 

Error types for the bridge. Bridge error types and helpers for mapping Python exceptions to Rust errors.

Enums

Error
All errors that can occur in the bridge layer.

Functions

with_retry
Retry f with exponential backoff on connection errors.
with_timeout
Run f with a timeout. Returns Error::Timeout if the future does not complete within timeout.