TriggerConfig

Enum TriggerConfig 

#[non_exhaustive]
pub enum TriggerConfig { Every { interval: Duration, }, OnFileChange { path: PathBuf, }, }
Configuration for a trigger that the SDK will run.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Every

Periodic trigger: fires every interval.

Fields

interval: Duration

Interval between firings.



OnFileChange

File-change trigger: fires when files change under path.

Fields

path: PathBuf

Directory to watch for changes.

Implementations

Source

impl TriggerConfig

pub const fn every_secs(secs: u64) -> Self

Create an Every trigger from a number of seconds.

Panics

Panics if secs is 0.

pub fn every(duration: Duration) -> Self

Create an Every trigger with a specific Duration.

Panics

Panics if the duration is less than 1 second.

pub fn on_file_change(path: impl Into<PathBuf>) -> Self

Create an OnFileChange trigger watching the given directory.

Panics

Panics if path is empty, relative, or contains ...

pub fn try_on_file_change(path: impl Into<PathBuf>) -> Result<Self, Error>

Fallible version of on_file_change.

Errors

Returns Error::InvalidConfig if path is empty, relative, or contains ...

pub fn try_every(duration: Duration) -> Result<Self, Error>

Fallible version of every.

Errors

Returns Error::InvalidConfig if the duration is less than 1 second.

pub fn description(&self) -> String

Human-readable description for logging.