Error types for the bridge. Bridge error types and helpers for mapping Python exceptions to Rust errors.
Enums
- Error
- All errors that can occur in the bridge layer.
Constants
- HTTP_
CODE_ UNKNOWN - Unset / unknown HTTP status code (
0). - HTTP_
SERVER_ ERROR_ MAX - End of the HTTP server error 5xx status code range (599).
- HTTP_
SERVER_ ERROR_ MIN - Start of the HTTP server error 5xx status code range (500).
- HTTP_
SERVICE_ UNAVAILABLE - HTTP status code for
Service Unavailable(503). - HTTP_
TOO_ MANY_ REQUESTS - HTTP status code for
Too Many Requests(429).
Functions
- http_
code_ is_ quota - Whether an HTTP status code denotes a quota / rate-limit condition.
- http_
code_ is_ retryable - Whether an HTTP status code denotes a transiently retryable failure.
- with_
timeout - Run
fwith a timeout. ReturnsError::Timeoutif the future does not complete withintimeout.