pub struct HookSet { /* private fields */ }Expand description
An ordered list of hooks to attach to an agent.
Hooks at the same HookPoint fire in registration order.
Implementations
Sourceimpl HookSet
impl HookSet
Sourcepub fn push(&mut self, entry: HookEntry) -> Result<(), Error>
pub fn push(&mut self, entry: HookEntry) -> Result<(), Error>
Register a hook.
If a hook with the same name AND hook point already exists, it is replaced and a warning is logged.
Errors
Returns Err if the entry fails validation (empty name or callback_id).